package Mail::DMARC::Report::IODEF;
{
  $Mail::DMARC::Report::IODEF::VERSION = '0.20130506';
}
use strict;
use warnings;

use parent 'Mail::DMARC::Report';

1;
# ABSTRACT: an IODEF report


=pod

=head1 NAME

Mail::DMARC::Report::IODEF - an IODEF report

=head1 VERSION

version 0.20130506

=head1 WHY IS THIS EMPTY?

https://datatracker.ietf.org/doc/draft-kucherawy-dmarc-base/?include_text=1

Section 3.5 Out of Scope:

    This first version of DMARC supports only a single reporting format.

=head1 AUTHORS

=over 4

=item *

Matt Simerson <msimerson@cpan.org>

=item *

Davide Migliavacca <shari@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by The Network People, Inc..

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

